==> ctxR_1.0.0.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/list/search/by-name/BIOSOLDIS2021-8b6df7.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/list/search/by-name/BIOSOLDIS2021?projection=chemicallistwithdtxsids", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Wed, 22 May 2024 19:50:17 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "bc670d68-6bf7-474b-4157-7cb9bc0f256f", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "3LMlKw3ahWxRTFIKbEnKlmEXp8ybpDFrZRkHcl-zLc0a6qobjRyCDA=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Wed, 22 May 2024 19:50:17 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "bc670d68-6bf7-474b-4157-7cb9bc0f256f", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 052215bfd8d35ecb703b208e875bd350.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "ATL59-P8", `x-amz-cf-id` = "3LMlKw3ahWxRTFIKbEnKlmEXp8ybpDFrZRkHcl-zLc0a6qobjRyCDA=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x4c, 0x69, 0x73, 0x74, 0x20, 0x6e, 0x61, 0x6d, 0x65, 0x20, 
    0x77, 0x69, 0x74, 0x68, 0x20, 0x76, 0x61, 0x6c, 0x75, 0x65, 
    0x20, 0x42, 0x49, 0x4f, 0x53, 0x4f, 0x4c, 0x44, 0x49, 0x53, 
    0x32, 0x30, 0x32, 0x31, 0x20, 0x6e, 0x6f, 0x74, 0x20, 0x66, 
    0x6f, 0x75, 0x6e, 0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 
    0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x2f, 0x73, 
    0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 0x6e, 
    0x61, 0x6d, 0x65, 0x2f, 0x42, 0x49, 0x4f, 0x53, 0x4f, 0x4c, 
    0x44, 0x49, 0x53, 0x32, 0x30, 0x32, 0x31, 0x22, 0x0a, 0x7d
    )), date = structure(1716407417, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 3.9e-05, 
    connect = 0, pretransfer = 0.000172, starttransfer = 0.015304, 
    total = 0.015336)), class = "response")

==> ctxR_1.1.0.tar.gz: ctxR/tests/testthat/chemical-batch/chemical/list/search/by-name/BIOSOLDIS2021-8b6df7.R <==
structure(list(url = "https://api-ccte.epa.gov/chemical/list/search/by-name/BIOSOLDIS2021?projection=chemicallistwithdtxsids", 
    status_code = 400L, headers = structure(list(`content-type` = "application/problem+json", 
        `transfer-encoding` = "chunked", connection = "keep-alive", 
        date = "Fri, 08 Nov 2024 15:35:15 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
        `strict-transport-security` = "max-age=31536000", `x-content-type-options` = "nosniff", 
        `x-vcap-request-id` = "05dcf5ce-1a61-4941-528a-c5f63d313d25", 
        `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
        `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
        `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "h5DGWniwzZHLcWmdw4S6LNdXHlea0xi4DAN7T2p9Kct8dcBrwyJzRQ=="), class = c("insensitive", 
    "list")), all_headers = list(list(status = 400L, version = "HTTP/1.1", 
        headers = structure(list(`content-type` = "application/problem+json", 
            `transfer-encoding` = "chunked", connection = "keep-alive", 
            date = "Fri, 08 Nov 2024 15:35:15 GMT", `cache-control` = "max-age=0, must-revalidate, no-transform", 
            `strict-transport-security` = "max-age=31536000", 
            `x-content-type-options` = "nosniff", `x-vcap-request-id` = "05dcf5ce-1a61-4941-528a-c5f63d313d25", 
            `x-xss-protection` = "1; mode=block", `x-frame-options` = "DENY", 
            `x-cache` = "Error from cloudfront", via = "1.1 e84404231b384141b3b0f51e40964ef6.cloudfront.net (CloudFront)", 
            `x-amz-cf-pop` = "IAD55-P7", `x-amz-cf-id` = "h5DGWniwzZHLcWmdw4S6LNdXHlea0xi4DAN7T2p9Kct8dcBrwyJzRQ=="), class = c("insensitive", 
        "list")))), cookies = structure(list(domain = logical(0), 
        flag = logical(0), path = logical(0), secure = logical(0), 
        expiration = structure(numeric(0), class = c("POSIXct", 
        "POSIXt")), name = logical(0), value = logical(0)), row.names = integer(0), class = "data.frame"), 
    content = as.raw(c(0x7b, 0x0a, 0x20, 0x20, 0x22, 0x74, 0x79, 
    0x70, 0x65, 0x22, 0x20, 0x3a, 0x20, 0x22, 0x61, 0x62, 0x6f, 
    0x75, 0x74, 0x3a, 0x62, 0x6c, 0x61, 0x6e, 0x6b, 0x22, 0x2c, 
    0x0a, 0x20, 0x20, 0x22, 0x74, 0x69, 0x74, 0x6c, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x42, 0x61, 0x64, 0x20, 0x52, 0x65, 
    0x71, 0x75, 0x65, 0x73, 0x74, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x73, 0x74, 0x61, 0x74, 0x75, 0x73, 0x22, 0x20, 0x3a, 
    0x20, 0x34, 0x30, 0x30, 0x2c, 0x0a, 0x20, 0x20, 0x22, 0x64, 
    0x65, 0x74, 0x61, 0x69, 0x6c, 0x22, 0x20, 0x3a, 0x20, 0x22, 
    0x4c, 0x69, 0x73, 0x74, 0x20, 0x6e, 0x61, 0x6d, 0x65, 0x20, 
    0x77, 0x69, 0x74, 0x68, 0x20, 0x76, 0x61, 0x6c, 0x75, 0x65, 
    0x20, 0x42, 0x49, 0x4f, 0x53, 0x4f, 0x4c, 0x44, 0x49, 0x53, 
    0x32, 0x30, 0x32, 0x31, 0x20, 0x6e, 0x6f, 0x74, 0x20, 0x66, 
    0x6f, 0x75, 0x6e, 0x64, 0x2e, 0x22, 0x2c, 0x0a, 0x20, 0x20, 
    0x22, 0x69, 0x6e, 0x73, 0x74, 0x61, 0x6e, 0x63, 0x65, 0x22, 
    0x20, 0x3a, 0x20, 0x22, 0x2f, 0x63, 0x68, 0x65, 0x6d, 0x69, 
    0x63, 0x61, 0x6c, 0x2f, 0x6c, 0x69, 0x73, 0x74, 0x2f, 0x73, 
    0x65, 0x61, 0x72, 0x63, 0x68, 0x2f, 0x62, 0x79, 0x2d, 0x6e, 
    0x61, 0x6d, 0x65, 0x2f, 0x42, 0x49, 0x4f, 0x53, 0x4f, 0x4c, 
    0x44, 0x49, 0x53, 0x32, 0x30, 0x32, 0x31, 0x22, 0x0a, 0x7d
    )), date = structure(1731080115, class = c("POSIXct", "POSIXt"
    ), tzone = "GMT"), times = c(redirect = 0, namelookup = 5.5e-05, 
    connect = 0, pretransfer = 0.000167, starttransfer = 0.25819, 
    total = 0.258222)), class = "response")
